@@ -20,7 +20,12 @@ from astropy import (cosmology,
 from .io import read_griddata_ascii
 from . import registry
 from .spectral import get_bandpass, get_magsystem, Bandpass
-from ._extinction import ccm89, od94, f99kknots, f99uv
+try:
+    # Not guaranteed available at setup time
+    from ._extinction import ccm89, od94, f99kknots, f99uv
+except ImportError:
+    if not _ASTROPY_SETUP_:
+        raise
 
 __all__ = ['get_source', 'Source', 'TimeSeriesSource', 'StretchSource',
            'SALT2Source', 'Model',
@@ -929,11 +934,27 @@ class Model(_ModelBase):
 
     def minwave(self):
         """Minimum observer-frame wavelength of the model."""
-        return self._source.minwave() * (1. + self._parameters[0])
+        shift = (1. + self._parameters[0])
+        max_minwave = self._source.minwave() * shift 
+        for effect, frame in zip(self._effects, self._effect_frames):
+            effect_minwave = effect.minwave()
+            if frame == 'rest':
+                effect_minwave *= shift
+            if effect_minwave > max_minwave :
+                max_minwave = effect_minwave
+        return max_minwave
 
     def maxwave(self):
         """Maximum observer-frame wavelength of the model."""
-        return self._source.maxwave() * (1. + self._parameters[0])
+        shift = (1. + self._parameters[0])
+        min_maxwave = self._source.maxwave() * shift 
+        for effect, frame in zip(self._effects, self._effect_frames):
+            effect_maxwave = effect.maxwave()
+            if frame == 'rest':
+                effect_maxwave *= shift
+            if effect_maxwave < min_maxwave :
+                min_maxwave = effect_maxwave
+        return min_maxwave
 
     # ----------------------------------------------------------------
     # Flux
